{ config, pkgs, ... }: let
  image = name: "ghcr.io/genudine/${name}/${name}:latest";
  port = n: builtins.toString ( 8201 + (n * 100) );
in {
  sops.secrets.metagame = {
    sopsFile = ../../../secrets/ps2live/saerro.yaml;
  };

  virtualisation.oci-containers.containers = {
    metagame = {
      image = image "metagame";
      environment = {
        PORT = port 1;
      };
      ports = [ "${port 1}:${port 1}" ];
      environmentFiles = [
        config.sops.secrets.metagame.path
      ];
    };

    aggpop = {
      image = image "agg-population";
      environment = {
        PORT = port 0;
      };
      ports = [ "${port 0}:${port 0}" ];
    };
  };

  systemd.services.restart-upgrade-aggmeta = {
    serviceConfig.Type = "oneshot";
    script = ''
      ${pkgs.podman}/bin/podman pull ${config.virtualisation.oci-containers.containers.metagame.image}
      ${pkgs.podman}/bin/podman pull ${config.virtualisation.oci-containers.containers.aggpop.image}

      systemctl restart podman-aggpop
      systemctl restart podman-metagame
    '';
  };

  systemd.timers.restart-upgrade-aggmeta = {
    wantedBy = [ "timers.target" ];
    timerConfig = {
      Unit = "restart-upgrade-aggmeta.service";
      OnUnitActiveSec = "360m";
    };
  };
}
